==> blesta-5.10.2.zip: blesta/components/modules/ispmanager/language/tr_tr/ispmanager.php <==
<?php
/**
 * Ispmanager
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Ispmanager.!error.meta[template].empty'] = 'Bir Şablon gereklidir.';
$lang['Ispmanager.!error.name_servers_count'] = 'En az 2 ad sunucusu tanımlamanız gerekir.';
$lang['Ispmanager.!error.name_servers_valid'] = 'Girilen ad sunucularından biri veya daha fazlası geçersiz.';
$lang['Ispmanager.!error.account_limit_valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['Ispmanager.!error.password_valid_connection'] = 'Sunucuyla bağlantı kurulamadı. Lütfen Kullanıcı Adı ve Şifrenin doğru olduğundan emin olmak için kontrol edin.';
$lang['Ispmanager.!error.password_valid'] = 'Şifre geçersiz görünüyor.';
$lang['Ispmanager.!error.api'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Ispmanager.!error.ispmanager_password.matches'] = 'Parola ve Parola Onayla eşleşmiyor.';
$lang['Ispmanager.!error.ispmanager_password.valid'] = 'Şifre en az 8 karakter uzunluğunda olmalıdır.';
$lang['Ispmanager.!error.ispmanager_username.length'] = 'Kullanıcı adı 1 ila 16 karakter uzunluğunda olmalıdır.';
$lang['Ispmanager.!error.ispmanager_username.test'] = 'Kullanıcı adı \'test\' ile başlayamaz.';
$lang['Ispmanager.!error.ispmanager_username.format'] = 'Kullanıcı adı sadece harf ve rakamlardan oluşabilir.';
$lang['Ispmanager.!error.ispmanager_domain.test'] = 'Alan adı \'test\' ile başlayamaz.';
$lang['Ispmanager.!error.ispmanager_domain.format'] = 'Lütfen geçerli bir alan adı girin, örn. domain.com.';
$lang['Ispmanager.!error.module_row.missing'] = 'Dahili bir hata oluştu. Modül satırı kullanılamıyor.';
$lang['Ispmanager.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Ispmanager.!error.user_name_valid'] = 'Kullanıcı Adı geçersiz görünüyor.';
$lang['Ispmanager.!error.host_name_valid'] = 'Ana Bilgisayar Adı geçersiz görünüyor.';
$lang['Ispmanager.!error.server_name_valid'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['Ispmanager.service_field.tooltip.password'] = 'Otomatik olarak bir şifre oluşturmak için şifreyi boş bırakabilirsiniz.';
$lang['Ispmanager.service_field.tooltip.username'] = 'Otomatik olarak bir kullanıcı adı oluşturmak için kullanıcı adını boş bırakabilirsiniz.';
$lang['Ispmanager.service_field.tooltip.username_edit'] = 'Bu değişiklik ispmanager\'ı etkilemeyecek, sadece Blesta\'daki yerel kaydı değiştirecektir.';
$lang['Ispmanager.service_field.tooltip.domain_edit'] = 'Bu değişiklik ispmanager\'ı etkilemeyecek, sadece Blesta\'daki yerel kaydı değiştirecektir.';
$lang['Ispmanager.service_info.option_login'] = 'Giriş yap';
$lang['Ispmanager.service_info.options'] = 'Seçenekler';
$lang['Ispmanager.service_info.server'] = 'Sunucu';
$lang['Ispmanager.service_info.password'] = 'Şifre';
$lang['Ispmanager.service_info.username'] = 'Kullanıcı Adı';
$lang['Ispmanager.service_field.password'] = 'Şifre';
$lang['Ispmanager.service_field.username'] = 'Kullanıcı Adı';
$lang['Ispmanager.service_field.domain'] = 'Etki Alanı';
$lang['Ispmanager.package_fields.template'] = 'Şablon';
$lang['Ispmanager.tab_client_actions.field_password_submit'] = 'Şifreyi Güncelle';
$lang['Ispmanager.tab_client_actions.field_ispmanager_confirm_password'] = 'Şifreyi Onayla';
$lang['Ispmanager.tab_client_actions.field_ispmanager_password'] = 'Şifre';
$lang['Ispmanager.tab_client_actions.change_password'] = 'Şifre Değiştir';
$lang['Ispmanager.row_meta.account_limit'] = 'Hesap Limiti';
$lang['Ispmanager.row_meta.use_ssl'] = 'API\'ye bağlanırken SSL kullanın (önerilir)';
$lang['Ispmanager.row_meta.password'] = 'Şifre';
$lang['Ispmanager.row_meta.user_name'] = 'Kullanıcı Adı';
$lang['Ispmanager.row_meta.host_name'] = 'Ana bilgisayar adı';
$lang['Ispmanager.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['Ispmanager.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['Ispmanager.edit_row.remove_name_server'] = 'Kaldırmak';
$lang['Ispmanager.edit_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Ispmanager.edit_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Ispmanager.edit_row.name_server_col'] = 'İsim Sunucusu';
$lang['Ispmanager.edit_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Ispmanager.edit_row.notes_title'] = 'Notlar';
$lang['Ispmanager.edit_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Ispmanager.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['Ispmanager.edit_row.box_title'] = 'ispmanager Sunucusunu Düzenleme';
$lang['Ispmanager.add_row.add_btn'] = 'Sunucu Ekle';
$lang['Ispmanager.add_row.remove_name_server'] = 'Kaldırmak';
$lang['Ispmanager.add_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Ispmanager.add_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Ispmanager.add_row.name_server_col'] = 'İsim Sunucusu';
$lang['Ispmanager.add_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Ispmanager.add_row.notes_title'] = 'Notlar';
$lang['Ispmanager.add_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Ispmanager.add_row.basic_title'] = 'Temel Ayarlar';
$lang['Ispmanager.add_row.box_title'] = 'ispmanager Sunucusu Ekleme';
$lang['Ispmanager.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['Ispmanager.order_options.first'] = 'İlk Dolu Olmayan Sunucu';
$lang['Ispmanager.manage.module_groups_no_results'] = 'Sunucu grubu yoktur.';
$lang['Ispmanager.manage.module_rows_no_results'] = 'Sunucu yok.';
$lang['Ispmanager.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['Ispmanager.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['Ispmanager.manage.module_groups.delete'] = 'Silme';
$lang['Ispmanager.manage.module_rows.delete'] = 'Silme';
$lang['Ispmanager.manage.module_groups.edit'] = 'Düzenle';
$lang['Ispmanager.manage.module_rows.edit'] = 'Düzenle';
$lang['Ispmanager.manage.module_rows.count'] = '1$s / %2$s';
$lang['Ispmanager.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['Ispmanager.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['Ispmanager.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['Ispmanager.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['Ispmanager.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['Ispmanager.manage.module_rows_heading.hostname'] = 'Ana bilgisayar adı';
$lang['Ispmanager.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['Ispmanager.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['Ispmanager.manage.module_rows_title'] = 'Sunucular';
$lang['Ispmanager.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['Ispmanager.add_module_row'] = 'Sunucu Ekle';
$lang['Ispmanager.tab_client_actions'] = 'Eylemler';
$lang['Ispmanager.module_group'] = 'Sunucu Grubu';
$lang['Ispmanager.module_row_plural'] = 'Sunucular';
$lang['Ispmanager.module_row'] = 'Sunucu';
$lang['Ispmanager.description'] = 'ispmanager, web sitelerini yönetmek, kullanıcılar oluşturmak, alan adlarını, e-postaları, veritabanlarını vb. işlemek için zengin özellikler sunar.';
$lang['Ispmanager.name'] = 'ispmanager';

==> blesta-5.11.4.zip: blesta/components/modules/ispmanager/language/tr_tr/ispmanager.php <==
<?php
/**
 * Ispmanager
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Ispmanager.!error.meta[template].empty'] = 'Bir Şablon gereklidir.';
$lang['Ispmanager.!error.name_servers_count'] = 'En az 2 ad sunucusu tanımlamanız gerekir.';
$lang['Ispmanager.!error.name_servers_valid'] = 'Girilen ad sunucularından biri veya daha fazlası geçersiz.';
$lang['Ispmanager.!error.account_limit_valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['Ispmanager.!error.password_valid_connection'] = 'Sunucuyla bağlantı kurulamadı. Lütfen Kullanıcı Adı ve Şifrenin doğru olduğundan emin olmak için kontrol edin.';
$lang['Ispmanager.!error.password_valid'] = 'Şifre geçersiz görünüyor.';
$lang['Ispmanager.!error.api'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Ispmanager.!error.ispmanager_password.matches'] = 'Parola ve Parola Onayla eşleşmiyor.';
$lang['Ispmanager.!error.ispmanager_password.valid'] = 'Şifre en az 8 karakter uzunluğunda olmalıdır.';
$lang['Ispmanager.!error.ispmanager_username.length'] = 'Kullanıcı adı 1 ila 16 karakter uzunluğunda olmalıdır.';
$lang['Ispmanager.!error.ispmanager_username.test'] = 'Kullanıcı adı \'test\' ile başlayamaz.';
$lang['Ispmanager.!error.ispmanager_username.format'] = 'Kullanıcı adı sadece harf ve rakamlardan oluşabilir.';
$lang['Ispmanager.!error.ispmanager_domain.test'] = 'Alan adı \'test\' ile başlayamaz.';
$lang['Ispmanager.!error.ispmanager_domain.format'] = 'Lütfen geçerli bir alan adı girin, örn. domain.com.';
$lang['Ispmanager.!error.module_row.missing'] = 'Dahili bir hata oluştu. Modül satırı kullanılamıyor.';
$lang['Ispmanager.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['Ispmanager.!error.user_name_valid'] = 'Kullanıcı Adı geçersiz görünüyor.';
$lang['Ispmanager.!error.host_name_valid'] = 'Ana Bilgisayar Adı geçersiz görünüyor.';
$lang['Ispmanager.!error.server_name_valid'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['Ispmanager.service_field.tooltip.password'] = 'Otomatik olarak bir şifre oluşturmak için şifreyi boş bırakabilirsiniz.';
$lang['Ispmanager.service_field.tooltip.username'] = 'Otomatik olarak bir kullanıcı adı oluşturmak için kullanıcı adını boş bırakabilirsiniz.';
$lang['Ispmanager.service_field.tooltip.username_edit'] = 'Bu değişiklik ispmanager\'ı etkilemeyecek, sadece Blesta\'daki yerel kaydı değiştirecektir.';
$lang['Ispmanager.service_field.tooltip.domain_edit'] = 'Bu değişiklik ispmanager\'ı etkilemeyecek, sadece Blesta\'daki yerel kaydı değiştirecektir.';
$lang['Ispmanager.service_info.option_login'] = 'Giriş yap';
$lang['Ispmanager.service_info.options'] = 'Seçenekler';
$lang['Ispmanager.service_info.server'] = 'Sunucu';
$lang['Ispmanager.service_info.password'] = 'Şifre';
$lang['Ispmanager.service_info.username'] = 'Kullanıcı Adı';
$lang['Ispmanager.service_field.password'] = 'Şifre';
$lang['Ispmanager.service_field.username'] = 'Kullanıcı Adı';
$lang['Ispmanager.service_field.domain'] = 'Etki Alanı';
$lang['Ispmanager.package_fields.template'] = 'Şablon';
$lang['Ispmanager.tab_client_actions.field_password_submit'] = 'Şifreyi Güncelle';
$lang['Ispmanager.tab_client_actions.field_ispmanager_confirm_password'] = 'Şifreyi Onayla';
$lang['Ispmanager.tab_client_actions.field_ispmanager_password'] = 'Şifre';
$lang['Ispmanager.tab_client_actions.change_password'] = 'Şifre Değiştir';
$lang['Ispmanager.row_meta.account_limit'] = 'Hesap Limiti';
$lang['Ispmanager.row_meta.use_ssl'] = 'API\'ye bağlanırken SSL kullanın (önerilir)';
$lang['Ispmanager.row_meta.password'] = 'Şifre';
$lang['Ispmanager.row_meta.user_name'] = 'Kullanıcı Adı';
$lang['Ispmanager.row_meta.host_name'] = 'Ana bilgisayar adı';
$lang['Ispmanager.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['Ispmanager.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['Ispmanager.edit_row.remove_name_server'] = 'Kaldırmak';
$lang['Ispmanager.edit_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Ispmanager.edit_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Ispmanager.edit_row.name_server_col'] = 'İsim Sunucusu';
$lang['Ispmanager.edit_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Ispmanager.edit_row.notes_title'] = 'Notlar';
$lang['Ispmanager.edit_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Ispmanager.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['Ispmanager.edit_row.box_title'] = 'ispmanager Sunucusunu Düzenleme';
$lang['Ispmanager.add_row.add_btn'] = 'Sunucu Ekle';
$lang['Ispmanager.add_row.remove_name_server'] = 'Kaldırmak';
$lang['Ispmanager.add_row.name_server'] = 'İsim sunucusu %1$s';
$lang['Ispmanager.add_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['Ispmanager.add_row.name_server_col'] = 'İsim Sunucusu';
$lang['Ispmanager.add_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['Ispmanager.add_row.notes_title'] = 'Notlar';
$lang['Ispmanager.add_row.name_servers_title'] = 'İsim Sunucuları';
$lang['Ispmanager.add_row.basic_title'] = 'Temel Ayarlar';
$lang['Ispmanager.add_row.box_title'] = 'ispmanager Sunucusu Ekleme';
$lang['Ispmanager.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['Ispmanager.order_options.first'] = 'İlk Dolu Olmayan Sunucu';
$lang['Ispmanager.manage.module_groups_no_results'] = 'Sunucu grubu yoktur.';
$lang['Ispmanager.manage.module_rows_no_results'] = 'Sunucu yok.';
$lang['Ispmanager.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['Ispmanager.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['Ispmanager.manage.module_groups.delete'] = 'Silme';
$lang['Ispmanager.manage.module_rows.delete'] = 'Silme';
$lang['Ispmanager.manage.module_groups.edit'] = 'Düzenle';
$lang['Ispmanager.manage.module_rows.edit'] = 'Düzenle';
$lang['Ispmanager.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['Ispmanager.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['Ispmanager.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['Ispmanager.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['Ispmanager.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['Ispmanager.manage.module_rows_heading.hostname'] = 'Ana bilgisayar adı';
$lang['Ispmanager.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['Ispmanager.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['Ispmanager.manage.module_rows_title'] = 'Sunucular';
$lang['Ispmanager.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['Ispmanager.add_module_row'] = 'Sunucu Ekle';
$lang['Ispmanager.tab_client_actions'] = 'Eylemler';
$lang['Ispmanager.module_group'] = 'Sunucu Grubu';
$lang['Ispmanager.module_row_plural'] = 'Sunucular';
$lang['Ispmanager.module_row'] = 'Sunucu';
$lang['Ispmanager.description'] = 'ispmanager, web sitelerini yönetmek, kullanıcılar oluşturmak, alan adlarını, e-postaları, veritabanlarını vb. işlemek için zengin özellikler sunar.';
$lang['Ispmanager.name'] = 'ispmanager';
$lang['Ispmanager.manage.module_rows.count'] = '%1$s / %2$s';
